# Telephone Contacts
A list of telephone contacts for the selected person/company saved in the database. Telephone contacts will also include data from a person's primary employer. If the person has no primary employer it will include contacts from every one of its employers.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Location:
The contact's location of use. Can be one of four locations: Work, Private, Home or Other. Work will be selected by default when creating a new contact.

### Type:
The telephone's type. Can be one of four types: Fix, Cell, Fax or Other. Fix will be selected by default.

### Number:
The telephone number.

## Primary Functionality:
Primary telephone contacts cannot be deleted unless they are the entry's last telephone contact. You need to make one of the other contacts their primary telephone contact before being able to delete that contact.

## Legend:
Click on the legend to filter primary telephone contacts. When displaying telephone contacts of a person you can also filter contacts belonging to the person's employer(s) by clicking on the legend "Company Contact".

## Search Field:
Typing in the search field allows to filter the telephone contacts by their number.
